@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -26,7 +26,7 @@
 
 #include "command.h"
 
-#include <qnamespace.h>
+#include <QtGui/QKeySequence>
 
 class WeldCommand : public Command
 {
