@@ -252,8 +252,13 @@ void ModelViewport::resizeGL( int w, int h )
       h = 1;
    }
 
-   m_viewportWidth  = w;
-   m_viewportHeight = h;
+   // FIXME?: I think Qt 5.6 (or later) changed resizeGL() behavior from
+   // always being pixels to points that need to be scaled but I don't
+   // have convient access to test old Qt versions. So using w and h or
+   // scaling them should potentially have a Qt version check.
+
+   m_viewportWidth  = w * devicePixelRatioF();
+   m_viewportHeight = h * devicePixelRatioF();
 
    adjustViewport();
 }
@@ -860,6 +865,7 @@ void ModelViewport::drawBackground()
          glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE );
          glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE );
          glEnable( GL_TEXTURE_2D );
+         glEnable( GL_BLEND );
 
          glBegin( GL_QUADS );
 
@@ -955,6 +961,8 @@ void ModelViewport::drawBackground()
          }
 
          glEnd();
+
+         glDisable( GL_BLEND );
       }
    }
 }
