@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -28,7 +28,7 @@
 
 #include "model.h"
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 class ViewPanel;
 
