@@ -315,7 +315,6 @@ ViewWindow::ViewWindow( Model * model, QWidget * parent )
    m_statusBar = new StatusBar( m_model, mainWidget );
    mainWidget->addWidgetToLayout( m_statusBar );
    m_statusBar->setText( tr( "Press F1 for help using any window" ).toUtf8() );
-   m_statusBar->setMaximumHeight( 30 );
 
    m_animWin = new AnimWindow( m_model, false, this );
    m_animWin->setObjectName( "mainwin_animwin" );
@@ -2551,15 +2550,15 @@ void ViewWindow::quitEvent()
 
 void ViewWindow::pluginWindowEvent()
 {
-   // pluginWin will delete itself view WDestructiveClose
+   // PluginWindow will delete itself
    PluginWindow * pluginWin = new PluginWindow();
    pluginWin->show();
 }
 
 void ViewWindow::backgroundWindowEvent()
 {
-   // pluginWin will delete itself view WDestructiveClose
-   BackgroundWin * win = new BackgroundWin( m_model );  
+   // BackgroundWin will delete itself
+   BackgroundWin * win = new BackgroundWin( m_model, m_viewPanel );
    win->show();
 }
 
