@@ -93,9 +93,9 @@ static void _setMaterial( DrawingContext * context, int texture, Model::Material
             context->m_matTextures[ context->m_currentTexture ] );
 
       glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, 
-            material->m_sClamp ? GL_CLAMP : GL_REPEAT);
+            material->m_sClamp ? GL_CLAMP_TO_EDGE : GL_REPEAT);
       glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, 
-            material->m_tClamp ? GL_CLAMP : GL_REPEAT);
+            material->m_tClamp ? GL_CLAMP_TO_EDGE : GL_REPEAT);
    }
 }
 
@@ -736,12 +736,12 @@ void BspTree::Node::render( float * point, DrawingContext * context )
 
 void BspTree::Poly::stats()
 {
-   log_debug( "BspTree::Poly: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "BspTree::Poly: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 void BspTree::Node::stats()
 {
-   log_debug( "BspTree::Node: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "BspTree::Node: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 int BspTree::Poly::flush()
