@@ -2082,7 +2082,7 @@ Model::ModelErrorE Md3Filter::writeSectionFile( const char * filename, Md3Filter
                saveMatrix = getMatrixFromPoint( a, t, rootTag ).getInverse();
             }
             list<int>::iterator vit;
-            double dmax[4] = { DBL_MIN, DBL_MIN, DBL_MIN, 1 };
+            double dmax[4] = { -DBL_MAX, -DBL_MAX, -DBL_MAX, 1 };
             double dmin[4] = { DBL_MAX, DBL_MAX, DBL_MAX, 1 };
             for ( mlit = meshes.begin(); mlit != meshes.end(); mlit++ )
             {
