@@ -27,10 +27,9 @@
 #include "log.h"
 #include "texmgr.h"
 
-#include <vector>
-#include <ext/hash_map>
+#include <unordered_map>
 
-using __gnu_cxx::hash_map;
+using std::unordered_map;
 
 
 Model * Model::copySelected() const
@@ -46,11 +45,11 @@ Model * Model::copySelected() const
    list<int> proj;
    this->getSelectedProjections( proj );
 
-   hash_map<int,int> projMap;
-   hash_map<int,int> vertMap;
-   hash_map<int,int> triMap;
-   hash_map<int,int> jointMap;
-   hash_map<int,int> pointMap;
+   unordered_map<int,int> projMap;
+   unordered_map<int,int> vertMap;
+   unordered_map<int,int> triMap;
+   unordered_map<int,int> jointMap;
+   unordered_map<int,int> pointMap;
 
    list<int>::iterator lit;
 
@@ -90,7 +89,7 @@ Model * Model::copySelected() const
       this->getSelectedVertices( vert );
 
       // Copy vertices
-      log_debug( "Copying %d vertices\n", vert.size() );
+      log_debug( "Copying %" PORTuSIZE " vertices\n", vert.size() );
       for ( lit = vert.begin(); lit != vert.end(); lit++ )
       {
          double coords[3];
@@ -103,7 +102,7 @@ Model * Model::copySelected() const
       }
 
       // Copy faces
-      log_debug( "Copying %d faces\n", tri.size() );
+      log_debug( "Copying %" PORTuSIZE " faces\n", tri.size() );
       for ( lit = tri.begin(); lit != tri.end(); lit++ )
       {
          unsigned v[3];
@@ -119,7 +118,7 @@ Model * Model::copySelected() const
       }
 
       // Copy texture coords
-      log_debug( "Copying %d face texture coordinates\n", tri.size() );
+      log_debug( "Copying %" PORTuSIZE " face texture coordinates\n", tri.size() );
       for ( lit = tri.begin(); lit != tri.end(); lit++ )
       {
          float s;
@@ -151,6 +150,7 @@ Model * Model::copySelected() const
                break;
             default:
                log_error( "Unknown material type %d in duplicate\n", this->getMaterialType(t) );
+               /* fall-through */
             case Model::Material::MATTYPE_BLANK:
                m->addColorMaterial( this->getTextureName( t ) );
                break;
@@ -191,7 +191,7 @@ Model * Model::copySelected() const
       if ( gcount > 0 )
       {
          // Set groups
-         log_debug( "Setting %d triangle groups\n", tri.size() );
+         log_debug( "Setting %" PORTuSIZE " triangle groups\n", tri.size() );
          for ( lit = tri.begin(); lit != tri.end(); lit++ )
          {
             // This works, even if triangle group == -1
@@ -208,7 +208,7 @@ Model * Model::copySelected() const
    if ( !points.empty() )
    {
       // Copy points
-      log_debug( "Copying %d points\n", points.size() );
+      log_debug( "Copying %" PORTuSIZE " points\n", points.size() );
       for ( lit = points.begin(); lit != points.end(); lit++ )
       {
          double coord[3];
@@ -228,7 +228,7 @@ Model * Model::copySelected() const
    if ( !joints.empty() )
    {
       // Copy joints
-      log_debug( "Copying %d joints\n", joints.size() );
+      log_debug( "Copying %" PORTuSIZE " joints\n", joints.size() );
       for ( lit = joints.begin(); lit != joints.end(); lit++ )
       {
          int parent = this->getBoneJointParent( *lit );
@@ -258,7 +258,7 @@ Model * Model::copySelected() const
          m->selectBoneJoint( nj );
       }
 
-      for ( hash_map<int,int>::iterator it = vertMap.begin();
+      for ( unordered_map<int,int>::iterator it = vertMap.begin();
             it != vertMap.end(); ++it )
       {
          InfluenceList il;
@@ -275,7 +275,7 @@ Model * Model::copySelected() const
          }
       }
 
-      for ( hash_map<int,int>::iterator it = pointMap.begin();
+      for ( unordered_map<int,int>::iterator it = pointMap.begin();
             it != pointMap.end(); ++it )
       {
          InfluenceList il;
